@@ -1,13 +1,14 @@
 class OverwriteError(Exception):
     pass
 
-class AccountNotExists(Exception):
+
+class AccountDoesNotExist(Exception):
     pass
 
+
 class BadPassphrase(Exception):
     pass
 
+
 class DecryptionFailed(Exception):
     pass
-
-
